pub(super) async fn authenticate(
state: &WebSocketServices,
socket: &mut WebSocket,
) -> Result<AuthenticatedJoin, HandshakeError>Expand description
returns the authenticated room join intent without admitting the user
pub(super) async fn authenticate(
state: &WebSocketServices,
socket: &mut WebSocket,
) -> Result<AuthenticatedJoin, HandshakeError>returns the authenticated room join intent without admitting the user